@@ -1,5 +1,5 @@
 """
-TkinterWeb v3.14
+TkinterWeb v3.15
 This is a wrapper for the Tkhtml3 widget from http://tkhtml.tcl.tk/tkhtml.html, 
 which displays styled HTML documents in Tkinter.
 
@@ -54,7 +54,7 @@ See https://github.com/Andereoo/TkinterWeb/blob/main/tkinterweb/docs/FAQ.md for
 
 __title__ = 'TkinterWeb'
 ___author__ = "Andereoo"
-__version__ = '3.13'
+__version__ = '3.15'
 __all__ = ['HtmlFrame', 'HtmlLabel', 'TkinterWeb', 'Demo']
 
 
@@ -73,7 +73,7 @@ class Demo():
         frame = HtmlFrame(root)
 
         frame.on_title_change(self.change_title)
-        frame.load_html("<mark>dfsdfg</mark>")
+        frame.load_url("https://wiki.python.org/moin/TkInter")
 
         frame.pack(expand=True, fill="both")
         root.mainloop()
